@@ -1,5 +1,5 @@
 
 from generalfile.path import Path
-from generalfile.errors import *
+from generalfile.errors import CaseSensitivityError, InvalidCharacterError
 
 Path.get_lock_dir().create_folder()
